#ifndef _UMIAD_H_
#define _UMIAD_H_


 /**
  * UMI adaptor descriptors
  */

#ifdef __cplusplus
extern "C" {
#endif

  /**
   * adaptor base class.
   * Same for all adaptors.
   */
  typedef struct {
    /** 
     * id of the derived class	
     *
     * 'i' isa
     * 'p' pci
     * 'u' usb
     * 'P' pcmcia
     */
    int _eClass;		
    const char *_szName;	/**< Adaptor name		*/
    const char *_szOrg;		/**< organization		*/
    const char *_szArch;	/**< Adaptor architecture 	*/
    const char *_szLic;		/**< License string or 0	*/
  } UmiAdapt; 


  /* 
   * flags for PCI region descriptors 
   * each region listed is mapped
   */
  #define RG_AMCC5920_CONF 001	/* AMCC local config region	*/
  #define RG_IOBASE 002		/* register region		*/
  #define RG_IOMEM 004		/* memory region		*/
  #define RG_ISMEM(x) (((x) & RG_IOMEM)!=0)

  #define MAX_PCI_REGION 2
  #define MAX_REGION MAX_PCI_REGION 
  #define MAX_DRIV 4		/* drivers per USB adaptor	*/

  /**
   * IO/MEM region descriptor
   */
  typedef struct {
    unsigned _f;		/**< what to do with this region	*/
    unsigned _l;		/**< region length in bytes		*/
    int _iBar;			/**< PCI bar offset, -1 = NIL		*/
  } RegionDesc ;

  /**
   * PCI bus specific adaptor descriptor.
   */
  typedef struct {
    UmiAdapt _ad;		/**< base class	*/
    void *_pArg;		/**< argument for the UMI constructor */

    struct {
      unsigned long _vid;		/**< vendor id		*/
      unsigned long _did;		/**< device id		*/
    } _id, _idSS;

    RegionDesc _mprd[MAX_PCI_REGION];	/**< region descriptors */
  } UmiAdaptPci; 

  typedef struct {
    UmiAdapt _ad;
    unsigned long _vid;
    unsigned long _pid;
    const char *_szMcuType;		/**< type of the MCU			*/
    const void *_pfwIdle;		/**< firmware for idle operation	*/
    const void *_pfwDiscon;		/**< firmware for disconnect operation	*/
    const void *_mppfw[MAX_DRIV];	/**< per driver firmware download data	*/
  } UmiAdaptUsb; 

  typedef struct {
    UmiAdapt _ad;
    void *_pArg;		/**< argument for the UMI constructor 	*/
    const int *_piSig;		/**< signature[_isaLen]			*/
    RegionDesc _rd;		/**< region descriptor			*/
  } UmiAdaptIsa; 

  typedef struct {		/* PCMCIA */
    UmiAdapt _ad;
    void *_pArg;		/**< argument for the UMI constructor   */
    RegionDesc _rd;		/**< region descriptor			*/
  } UmiAdaptPcm; 

  /**
   * list of implemented adapters
   */
  extern const UmiAdapt *mppad[];	

  /**
   * get the first region matching size
   */
  extern const RegionDesc* getRegionBySize(const UmiAdapt *pua, unsigned len);
 
#ifdef __cplusplus
}
#endif

#endif
